<?php
/**
 * @file
 * Contains \Drupal\user\Plugin\block\block\JqueryCountdownTimerBlock.
 */

namespace Drupal\jquery_countdown_timer\Plugin\Block;

use Drupal\block\BlockBase;
use Drupal\Component\Annotation\Plugin;
use Drupal\Core\Annotation\Translation;

/**
 * Provides a "Jquery Countdown Timer" block.
 *
 * @Plugin(
 *   id = "jquery_countdown_timer",
 *   admin_label = @Translation("Countdown Timer"),
 *   module = "jquery_countdown_timer"
 * )
 */
class JqueryCountdownTimerBlock extends BlockBase {

  /**
   * Overrides \Drupal\block\BlockBase::settings().
   */
  public function settings() {
    return array(
      'properties' => array(
        'administrative' => TRUE
      ),
      'font_size' => 28,
      'date' => date('Y-m-d G:i:s')
    );
  }
  /**
   * Overrides \Drupal\block\BlockBase::blockForm().
   */
  public function blockForm($form, &$form_state) {
    $form['jquery_countdown_timer_font_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Timer font size'),
      '#default_value' => $this->configuration['font_size']
    );
    $form['jquery_countdown_timer_date'] = array(
      '#type' => 'date',
      '#title' => t('Timer date'),
      '#default_value' => $this->configuration['date']
    );
    return $form;
  }

  /**
   * Overrides \Drupal\block\BlockBase::blockSubmit().
   */
  public function blockSubmit($form, &$form_state) {
    $this->configuration['font_size'] = $form_state['values']['jquery_countdown_timer_font_size'];
    $this->configuration['date'] = $form_state['values']['jquery_countdown_timer_date'];
  }

  /**
   * Implements \Drupal\block\BlockBase::build().
   */
  public function build() {
    $path_to_module = drupal_get_path('module', 'jquery_countdown_timer');
    $build = array();

    $build['#markup'] = "<div id='jquery-countdown-timer'></div>";
    $build['#markup'] .= "<div id='jquery-countdown-timer-note'></div>";

    $build['#attached']['js'][] = $path_to_module . '/js/jquery_countdown_timer.js';
    $build['#attached']['js'][] = $path_to_module . '/js/jquery_countdown_timer_init.js';
    $build['#attached']['css'][] = $path_to_module . '/css/jquery_countdown_timer.css';
    $build['#attached']['css'][] = array(
      'data' => '.countdownHolder {font-size: ' . $this->configuration['font_size'] . 'px}',
      'type' => 'inline',
    );

    //print_r($this->configuration['date']); die;

    $settings = array(
      'jquery_countdown_timer_date' => strtotime($this->configuration['date']),
    );
    $build['#attached']['js'][] = array(
      'data' =>  array('jquery_countdown_timer' => $settings),
      'type' => 'setting',
    );


//    $build = array(
//      '#theme' => 'jquery_countdown_timer_container',
//    );
//
    return $build;
  }
}
?>
